@@ -1,6 +1,6 @@
 package Bundle::InterchangeKitchenSink;
 
-$VERSION = '1.01';
+$VERSION = '1.02';
 
 1;
 
@@ -42,6 +42,10 @@ DBI
 
 Safe::Hole
 
+Set::Crontab
+
+Text::Query
+
 Tie::ShadowHash
 
 Business::UPS
